#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
#
# 2022-11-30: fixed CheckParameterRulespecWithoutItem (from CheckParameterRulespecWithItem)
#

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    FixedValue,
    Tuple,
)

from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)


def _parameter_valuespec_checkpoint_fw_ls():
    return Dictionary(
        elements=[
            ('always_ok',
             FixedValue(
                 True,
                 title=_('Always OK'),
                 totext=_('Always OK enabled'),
                 help=_('Always return state as OK.'),
             )),
            ('levels_lower',
             Tuple(
                 title=_('Time offset'),
                 help=_('This rule sets the parameters for the Cisco Spanning-Tree Topology Changes.'),
                 elements=[
                     Integer(title=_('Warning below'), minvalue=0, unit=_('Seconds'), default_value=900),
                     Integer(title=_('Critical below'), minvalue=0, unit=_('Seconds'), default_value=600),
                 ])),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name='stp_topo_change',
        group=RulespecGroupCheckParametersNetworking,
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_checkpoint_fw_ls,
        title=lambda: _('STP Topology change'),  # Cisco Spanning-Tree Topology Changes
    ))
